@@ -1,9 +1,5 @@
 import random
-
-
-
-
-
+from . import strutils
 
 
 
@@ -534,6 +530,10 @@ last_names = [
 ('郤', 1),
 ('钮', 1),
 ('鲍', 1),
+('徒', 1),
+('尉', 1),
+('人', 1),
+('尉迟', 1),
 ('东郭', 1),
 ('南宫', 1),
 ('夹谷', 1),
@@ -1257,29 +1257,77 @@ first_names = [
 ]
 
 last_names.sort(key=lambda x: x[1])
-last_names_choices = list("".join([name[0] * name[1] for name in last_names]))
-random.shuffle(last_names_choices)
-random.shuffle(last_names_choices)
+last_name_choices = []
+for last_name, weight in last_names:
+    last_name_choices += [last_name] * weight
+random.shuffle(last_name_choices)
+random.shuffle(last_name_choices)
 
-first_names_choices = list("".join([name[0] * name[1] for name in first_names]))
-first_names_choices = first_names_choices * 10
-random.shuffle(first_names_choices)
-random.shuffle(first_names_choices)
+first_name_choices = []
+for first_name, weight in first_names:
+    first_name_choices += [first_name] * weight
+first_name_choices = first_name_choices * 10
+random.shuffle(first_name_choices)
+random.shuffle(first_name_choices)
 
 
 def get_random_name(last_name=None, first_name_length=(1, 2)):
-    last_name = last_name or random.choice(last_names_choices) 
-    return last_name + "".join(random.choices(first_names_choices, k=random.randint(*first_name_length)))
+    """Get a random chinese name.
+
+    Example:
+
+    In [8]: for i in range(10):
+    ...:     print(nameutils.get_random_name())
+    ...:
+    沈岩慧
+    苗春佳
+    阴鹏然
+    孔佳
+    都小鑫
+    苏辉
+    扈川
+    李儒子
+    赵聚
+    都辉业
+    """
+    last_name = last_name or random.choice(last_name_choices) 
+    return last_name + "".join(random.choices(first_name_choices, k=random.randint(*first_name_length)))
 
 
 def get_last_names():
+    """Get chineses last names.
+
+    Usage:
+
+    In [6]: print(",".join(nameutils.get_last_names()))
+    乐,亢,何,侍,关,农,刘,南,司马,安,宓,尧.....
+    """
     return [x[0] for x in last_names]
 
 def get_suggest_first_names():
+    """Get suggest first name characters.
+
+    Usage:
+
+    In [7]: print(",".join(nameutils.get_suggest_first_names()))
+    江,晓,伟,鹏,杰,俊,涛,佳,超,婷,志,飞,斌......
+    """
     return [x[0] for x in first_names]
 
 
-def guess_surname(fullname):
+def guess_lastname(fullname):
+    """Guess last name from fullname.
+
+    Usage:
+
+    In [18]: name = nameutils.get_random_name()
+
+    In [19]: print(name)
+    楼凯崇
+
+    In [20]: print(nameutils.guess_surname(name))
+    楼
+    """
     sns = []
     for sn, _ in last_names:
         if fullname.startswith(sn):
@@ -1290,4 +1338,16 @@ def guess_surname(fullname):
             final_sn = sn
     if final_sn:
         return final_sn
-    return fullname.split()[-1]
+
+    is_chinese = False
+    for c in fullname:
+        if strutils.is_chinese_character(c):
+            is_chinese = True
+            break
+    if is_chinese:
+        return fullname.strip()[0] # 如果有中文，则视为中文姓名，姓为第1个字符。
+    else:
+        return fullname.split()[-1] # 如果有中文，则视为英文姓名，姓为最后1个单词。
+
+
+guess_surname = guess_lastname # 保持旧版本兼容
